import json
import logging
from pathlib import Path
import sys


class ConfigJson(object):
    def __init__(self, file_path: Path, default_config: dict, stop_if_first: bool = True) -> None:
        self.file_path = file_path.absolute()
        self.default_config = default_config
        if not (file_path.is_file()):
            self._create_setting(default_config)
            logging.warning("Впервые создали конфиг, заполните его данными.")
            if stop_if_first:
                sys.exit()

    def _create_setting(self):
        json_string = json.dumps(self.default_config, indent=4)
        Path(self.file_path.parent).mkdir(exist_ok=True, parents=True)
        with open(self.file_path, "w") as file:
            file.write(json_string)

    def get_setting(self, section, key):
        with open(self.file_path, "r") as file:
            data = json.load(file)
        try:
            return data[section][key]
        except KeyError:
            self.set_setting(section, key, self.default_config[section][key])
            return self.default_config[section][key]

    def set_setting(self, section, key, value):
        with open(self.file_path, "r") as file:
            data = json.load(file)
        try:
            data[section][key] = value
        except KeyError:
            data[section] = {}
            data[section][key] = value
        json_string = json.dumps(data, indent=4)
        with open(self.file_path, "w") as file:
            file.write(json_string)
